@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2011-2017 by Andrew Mustun. All rights reserved.
+ * Copyright (c) 2011-2018 by Andrew Mustun. All rights reserved.
  *
  * This file is part of the QCAD project.
  *
@@ -117,6 +117,13 @@ ConvertUnit.convert = function(di, fromUnit, toUnit) {
             continue;
         }
 
+        var blockId = entity.getBlockId();
+        var block = doc.queryBlockDirect(blockId);
+        if (!isNull(block) && block.isPixelUnit()) {
+            // don't touch entities in pixel unit blocks:
+            continue;
+        }
+
         // don't scale block references as block content is scaled instead:
         if (isBlockReferenceEntity(entity)) {
             var p = entity.getPosition();
@@ -201,7 +208,7 @@ ConvertUnit.convert = function(di, fromUnit, toUnit) {
 
     //var offset = Print.getOffset(doc);
     //offset.scale(factor);
-    //Print.setOffset(doc, offset);
+    //Print.setOffset(di, offset);
 
     doc.rebuildSpatialIndex();
 
