@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2011-2017 by Andrew Mustun. All rights reserved.
+ * Copyright (c) 2011-2018 by Andrew Mustun. All rights reserved.
  * 
  * This file is part of the QCAD project.
  *
@@ -24,7 +24,7 @@
  * \brief This module contains ECMAScript implementations of the
  * tools in the file menu.
  */
-include("../EAction.js");
+include("scripts/EAction.js");
 
 /**
  * \class File
@@ -141,7 +141,7 @@ File.getInitialSaveAsPath = function(filePath, extension) {
  *
  * \param parentWidget Parent widget or null
  * \param caption Dialog caption
- * \param path Initial path of the dialog
+ * \param path Initial path with file name of the dialog
  * \param fileName Initial file name to suggest to user
  * \param filterStrings Array of filter strings in the format 'My File Type (*.mft *.mftype)'
  *
@@ -168,20 +168,17 @@ File.getSaveFileName = function(parentWidget, caption, path, filterStrings) {
 
     fileDialog.setNameFilters(filterStrings);
     
-    //if (!isNull(fileName)) {
-        //var fileInfo = new QFileInfo(fileName);
-        fileDialog.selectFile(fiDir.completeBaseName());
+    fileDialog.selectFile(fiDir.completeBaseName());
 
-        if (fiDir.suffix().length!==0) {
-            // preselect first name filter that matches current extension:
-            for (var i=0; i<filterStrings.length; ++i) {
-                if (filterStrings[i].contains("*." + fiDir.suffix().toLowerCase())) {
-                    fileDialog.selectNameFilter(filterStrings[i]);
-                    break;
-                }
+    if (fiDir.suffix().length!==0) {
+        // preselect first name filter that matches current extension:
+        for (var i=0; i<filterStrings.length; ++i) {
+            if (filterStrings[i].contains("*." + fiDir.suffix().toLowerCase())) {
+                fileDialog.selectNameFilter(filterStrings[i]);
+                break;
             }
         }
-    //}
+    }
 
     fileDialog.setLabelText(QFileDialog.FileType, qsTr("Format:"));
 
