@@ -55,14 +55,16 @@ function usage() {
           + "                                 implemented in the given script.\n"
           + "-config [path]                   Reads and stores settings in a configuration file\n"
           + "                                 at the given location instead of the default location.\n"
+          + "-debug-action-order              Print action order information in menus\n"
           + "-enable-script-debugger          Enables the script debugger.\n"
           + "                                 NOT recommended as this may cause unexpected\n"
           + "                                 behavior when using QCAD.\n"
-          + "-debug-action-order              Print action order information in menus\n"
           + "-exec [script file] [options]    Executes the given script file directly\n"
           + "                                 after staring QCAD. Options after the script\n"
           + "                                 file are passed on to the script.\n"
           + "-help                            Displays this help.\n"
+          + "-ignore-script-files             Ignore script files on disk."
+          + "                                 Only load scripts from plugins if applicable."
           + "-locale [locale]                 Sets the locale to be used (overrides\n"
           + "                                 the language set in the preferences).\n"
           + "                                 E.g. '-locale de' starts QCAD in German.\n"
@@ -326,7 +328,7 @@ function loadTranslations(addOns, splash) {
         QCoreApplication.processEvents();
     }
 
-    RSettings.loadTranslations("Scripts_" + locale, ["scripts/ts"]);
+    RSettings.loadTranslations("Scripts_" + locale, [autoPath("scripts/ts")]);
 
     for (var i = 0; i < addOns.length; ++i) {
         var addOn = addOns[i];
@@ -580,12 +582,26 @@ function main() {
         }
 
         // look up slash screen override:
+        var maxPri = undefined;
         for (i=0; i<numPlugins; i++) {
             pluginInfo = RPluginLoader.getPluginInfo(i);
-            var s = pluginInfo.get(key);
-            if (!isNull(s)) {
-                fn = s;
-                qDebug("splash override: ", fn);
+
+            // override priority:
+            var pri = pluginInfo.get("OverridePriority");
+            if (!isNull(pri)) {
+                pri = parseInt(pri);
+            }
+            else {
+                // default to lowest priority:
+                pri = 0;
+            }
+
+            if (isNull(maxPri) || pri>maxPri) {
+                var s = pluginInfo.get(key);
+                if (!isNull(s)) {
+                    fn = s;
+                    maxPri = pri;
+                }
             }
         }
 
@@ -694,7 +710,7 @@ function main() {
 
     setUpDragAndDrop(appWin);
 
-    appWin.windowIcon = new QIcon("scripts/qcad_icon.png");
+    appWin.windowIcon = new QIcon(autoPath("scripts/qcad_icon.png"));
     if (!ignoreDockappWindows) {
         appWin.readSettings();
     }
